@@ -9,3 +9,8 @@ class TestServerNotification(TestCase):
             1,
             b"v@:@",
         )
+
+
+class TestCallableMetadata(TestCase):
+    def test_callable_metadata_is_sane(self):
+        self.assertCallableMetadataIsSane(ServerNotification)
